@@ -1,3 +1,3 @@
-from .read_dm import *
+from .read_dm import read_dm
 from .read_K2 import read_gatan_K2_bin
 from .empad import read_empad
