@@ -4,6 +4,15 @@ __all__ = ['kernels']
 
 kernels = {}
 
+############################# multicorr kernels #################################
+
+import os
+with open(os.path.join(os.path.dirname(__file__), "multicorr_row_kernel.cu"), 'r') as f:
+    kernels['multicorr_row_kernel'] = cp.RawKernel(f.read(), 'multicorr_row_kernel')
+
+with open(os.path.join(os.path.dirname(__file__), "multicorr_col_kernel.cu"), 'r') as f:
+    kernels['multicorr_col_kernel'] = cp.RawKernel(f.read(), 'multicorr_col_kernel')
+
 
 ############################# get_maximal_points ################################
 
@@ -11,21 +20,21 @@ kernels = {}
 These kernels are approximately 50x faster than the np.roll approach used in the CPU version,
 per my testing with 1024x1024 pixels and float64 on a Jetson Xavier NX.
 The boundary conditions are slightly different in this version, in that pixels on the edge
-of the frame are always false. This simplifies the indexing, and since in the Braggdisk 
-detection application an edgeBoundary is always applied in the case of subpixel detection, 
-this is not considered a problem. 
+of the frame are always false. This simplifies the indexing, and since in the Braggdisk
+detection application an edgeBoundary is always applied in the case of subpixel detection,
+this is not considered a problem.
 """
 
 maximal_pts_float32 = r'''
 extern "C" __global__
 void maximal_pts(const float *ar, bool *out, const double minAbsoluteIntensity, const long long sizex, const long long sizey, const long long N){
     int tid = blockDim.x * blockIdx.x + threadIdx.x;
-    int x = tid % sizex;
-    int y = tid / sizey; // Floor divide
+    int x = tid / sizey;
+    int y = tid % sizey;
     bool res = false;
     if (tid < N && x>0 && x<(sizex-1) && y>0 && y<(sizey-1)) {
         float val = ar[tid];
-        
+
         out[tid] = ( val > ar[tid + sizey]) &&
                     (val > ar[tid - sizey]) &&
                     (val > ar[tid + 1]) &&
@@ -45,12 +54,12 @@ maximal_pts_float64 = r'''
 extern "C" __global__
 void maximal_pts(const double *ar, bool *out, const double minAbsoluteIntensity, const long long sizex, const long long sizey, const long long N){
     int tid = blockDim.x * blockIdx.x + threadIdx.x;
-    int x = tid % sizex;
-    int y = tid / sizey; // Floor divide
+    int x = tid / sizey;
+    int y = tid % sizey;
     bool res = false;
     if (tid < N && x>0 && x<(sizex-1) && y>0 && y<(sizey-1)) {
         double val = ar[tid];
-        
+
         out[tid] = ( val > ar[tid + sizey]) &&
                     (val > ar[tid - sizey]) &&
                     (val > ar[tid + 1]) &&
@@ -72,7 +81,7 @@ kernels['maximal_pts_float64'] = cp.RawKernel(maximal_pts_float64,'maximal_pts')
 
 edge_boundary = r'''
 extern "C" __global__
-void edge_boundary(bool *ar, const long long edgeBoundary, 
+void edge_boundary(bool *ar, const long long edgeBoundary,
                 const long long sizex, const long long sizey, const long long N){
     int tid = blockDim.x * blockIdx.x + threadIdx.x;
     int x = tid % sizex;
@@ -85,4 +94,4 @@ void edge_boundary(bool *ar, const long long edgeBoundary,
 }
 '''
 
-kernels['edge_boundary'] = cp.RawKernel(edge_boundary,'edge_boundary')
\ No newline at end of file
+kernels['edge_boundary'] = cp.RawKernel(edge_boundary,'edge_boundary')
