@@ -3,7 +3,7 @@
 import numpy as np
 from numpy.linalg import lstsq
 
-from ...io import RealSlice
+from ...io.datastructure import RealSlice
 
 def get_reference_g1g2(g1g2_map, mask):
     """
@@ -25,12 +25,12 @@ def get_reference_g1g2(g1g2_map, mask):
             * **g2**: *(2-tuple)* second reference lattice vector (x,y)
     """
     assert isinstance(g1g2_map, RealSlice)
-    assert np.all([name in g1g2_map.slices.keys() for name in ('g1x','g1y','g2x','g2y')])
+    assert np.all([name in g1g2_map.slicelabels for name in ('g1x','g1y','g2x','g2y')])
     assert mask.dtype == bool
-    g1x = np.median(g1g2_map.slices['g1x'][mask])
-    g1y = np.median(g1g2_map.slices['g1y'][mask])
-    g2x = np.median(g1g2_map.slices['g2x'][mask])
-    g2y = np.median(g1g2_map.slices['g2y'][mask])
+    g1x = np.median(g1g2_map.get_slice('g1x').data[mask])
+    g1y = np.median(g1g2_map.get_slice('g1y').data[mask])
+    g2x = np.median(g1g2_map.get_slice('g2x').data[mask])
+    g2y = np.median(g1g2_map.get_slice('g2y').data[mask])
     return (g1x,g1y),(g2x,g2y)
 
 def get_strain_from_reference_g1g2(g1g2_map, g1, g2):
@@ -54,23 +54,23 @@ def get_strain_from_reference_g1g2(g1g2_map, g1, g2):
         (RealSlice) the strain map; contains the elements of the infinitessimal strain
         matrix, in the following 5 arrays:
 
-            * ``strain_map.slices['e_xx']``: change in lattice x-components with respect
+            * ``strain_map.get_slice('e_xx')``: change in lattice x-components with respect
               to x
-            * ``strain_map.slices['e_yy']``: change in lattice y-components with respect
+            * ``strain_map.get_slice('e_yy')``: change in lattice y-components with respect
               to y
-            * ``strain_map.slices['e_xy']``: change in lattice x-components with respect
+            * ``strain_map.get_slice('e_xy')``: change in lattice x-components with respect
               to y
-            * ``strain_map.slices['theta']``: rotation of lattice with respect to
+            * ``strain_map.get_slice('theta')``: rotation of lattice with respect to
               reference
-            * ``strain_map.slices['mask']``: 0/False indicates unknown values
+            * ``strain_map.get_slice('mask')``: 0/False indicates unknown values
 
         Note 1: the strain matrix has been symmetrized, so e_xy and e_yx are identical
     """
     assert isinstance(g1g2_map, RealSlice)
-    assert np.all([name in g1g2_map.slices.keys() for name in ('g1x','g1y','g2x','g2y','mask')])
+    assert np.all([name in g1g2_map.slicelabels for name in ('g1x','g1y','g2x','g2y','mask')])
 
     # Get RealSlice for output storage
-    R_Nx,R_Ny = g1g2_map.slices['g1x'].shape
+    R_Nx,R_Ny = g1g2_map.get_slice('g1x').shape
     strain_map = RealSlice(data=np.zeros((R_Nx,R_Ny,5)),
                            slicelabels=('e_xx','e_yy','e_xy','theta','mask'),
                            name='strain_map')
@@ -83,17 +83,17 @@ def get_strain_from_reference_g1g2(g1g2_map, g1, g2):
     for Rx in range(R_Nx):
         for Ry in range(R_Ny):
             # Get lattice vectors for DP at Rx,Ry
-            alpha = np.array([[g1g2_map.slices['g1x'][Rx,Ry],g1g2_map.slices['g1y'][Rx,Ry]],
-                              [g1g2_map.slices['g2x'][Rx,Ry],g1g2_map.slices['g2y'][Rx,Ry]]])
+            alpha = np.array([[g1g2_map.get_slice('g1x').data[Rx,Ry],g1g2_map.get_slice('g1y').data[Rx,Ry]],
+                              [g1g2_map.get_slice('g2x').data[Rx,Ry],g1g2_map.get_slice('g2y').data[Rx,Ry]]])
             # Get transformation matrix
             beta = lstsq(M, alpha, rcond=None)[0].T
 
             # Get the infinitesimal strain matrix
-            strain_map.slices['e_xx'][Rx,Ry] = 1 - beta[0,0]
-            strain_map.slices['e_yy'][Rx,Ry] = 1 - beta[1,1]
-            strain_map.slices['e_xy'][Rx,Ry] = -(beta[0,1]+beta[1,0])/2.
-            strain_map.slices['theta'][Rx,Ry] =  (beta[0,1]-beta[1,0])/2.
-            strain_map.slices['mask'][Rx,Ry] = g1g2_map.slices['mask'][Rx,Ry]
+            strain_map.get_slice('e_xx').data[Rx,Ry] = 1 - beta[0,0]
+            strain_map.get_slice('e_yy').data[Rx,Ry] = 1 - beta[1,1]
+            strain_map.get_slice('e_xy').data[Rx,Ry] = -(beta[0,1]+beta[1,0])/2.
+            strain_map.get_slice('theta').data[Rx,Ry] =  (beta[0,1]-beta[1,0])/2.
+            strain_map.get_slice('mask').data[Rx,Ry] = g1g2_map.get_slice('mask').data[Rx,Ry]
     return strain_map
 
 def get_strain_from_reference_region(g1g2_map, mask):
@@ -117,20 +117,20 @@ def get_strain_from_reference_region(g1g2_map, mask):
         (RealSlice) the strain map; contains the elements of the infinitessimal strain
         matrix, in the following 5 arrays:
 
-            * ``strain_map.slices['e_xx']``: change in lattice x-components with respect
+            * ``strain_map.get_slice('e_xx')``: change in lattice x-components with respect
               to x
-            * ``strain_map.slices['e_yy']``: change in lattice y-components with respect
+            * ``strain_map.get_slice('e_yy')``: change in lattice y-components with respect
               to y
-            * ``strain_map.slices['e_xy']``: change in lattice x-components with respect
+            * ``strain_map.get_slice('e_xy')``: change in lattice x-components with respect
               to y
-            * ``strain_map.slices['theta']``: rotation of lattice with respect to
+            * ``strain_map.get_slice('theta')``: rotation of lattice with respect to
               reference
-            * ``strain_map.slices['mask']``: 0/False indicates unknown values
+            * ``strain_map.get_slice('mask')``: 0/False indicates unknown values
 
         Note 1: the strain matrix has been symmetrized, so e_xy and e_yx are identical
     """
     assert isinstance(g1g2_map, RealSlice)
-    assert np.all([name in g1g2_map.slices.keys() for name in ('g1x','g1y','g2x','g2y','mask')])
+    assert np.all([name in g1g2_map.slicelabels for name in ('g1x','g1y','g2x','g2y','mask')])
     assert mask.dtype == bool
 
     g1,g2 = get_reference_g1g2(g1g2_map,mask)
@@ -150,18 +150,18 @@ def get_rotated_strain_map(unrotated_strain_map, xaxis_x, xaxis_y):
             along the new x-axis
         unrotated_strain_map (RealSlice): a RealSlice object containing 2D arrays of the
             infinitessimal strain matrix elements, stored at
-                * unrotated_strain_map.slices['e_xx']
-                * unrotated_strain_map.slices['e_xy']
-                * unrotated_strain_map.slices['e_yy']
-                * unrotated_strain_map.slices['theta']
+                * unrotated_strain_map.get_slice('e_xx')
+                * unrotated_strain_map.get_slice('e_xy')
+                * unrotated_strain_map.get_slice('e_yy')
+                * unrotated_strain_map.get_slice('theta')
 
     Returns:
         (RealSlice) the rotated counterpart to unrotated_strain_map, with the
-        rotated_strain_map.slices['e_xx'] element oriented along the new coordinate
+        rotated_strain_map.get_slice('e_xx') element oriented along the new coordinate
         system
     """
     assert isinstance(unrotated_strain_map, RealSlice)
-    assert np.all([key in ['e_xx','e_xy','e_yy','theta','mask'] for key in unrotated_strain_map.slices.keys()])
+    assert np.all([key in ['e_xx','e_xy','e_yy','theta','mask'] for key in unrotated_strain_map.slicelabels])
 
     theta = -np.arctan2(xaxis_y,xaxis_x)
     cost = np.cos(theta)
@@ -169,17 +169,17 @@ def get_rotated_strain_map(unrotated_strain_map, xaxis_x, xaxis_y):
     cost2 = cost**2
     sint2 = sint**2
 
-    Rx,Ry = unrotated_strain_map.slices['e_xx'].shape
+    Rx,Ry = unrotated_strain_map.get_slice('e_xx').data.shape
     rotated_strain_map = RealSlice(data=np.zeros((Rx,Ry,5)),
                                    slicelabels=['e_xx','e_xy','e_yy','theta','mask'],
                                    name=unrotated_strain_map.name+"_rotated".format(np.degrees(theta)))
 
-    rotated_strain_map.data[:,:,0] = cost2*unrotated_strain_map.slices['e_xx'] - 2*cost*sint*unrotated_strain_map.slices['e_xy'] + sint2*unrotated_strain_map.slices['e_yy']
-    rotated_strain_map.data[:,:,1] = cost*sint*(unrotated_strain_map.slices['e_xx']-unrotated_strain_map.slices['e_yy']) + (cost2-sint2)*unrotated_strain_map.slices['e_xy']
-    rotated_strain_map.data[:,:,2] = sint2*unrotated_strain_map.slices['e_xx'] + 2*cost*sint*unrotated_strain_map.slices['e_xy'] + cost2*unrotated_strain_map.slices['e_yy']
-    rotated_strain_map.data[:,:,3] = unrotated_strain_map.slices['theta']
+    rotated_strain_map.data[:,:,0] = cost2*unrotated_strain_map.get_slice('e_xx').data - 2*cost*sint*unrotated_strain_map.get_slice('e_xy').data + sint2*unrotated_strain_map.get_slice('e_yy').data
+    rotated_strain_map.data[:,:,1] = cost*sint*(unrotated_strain_map.get_slice('e_xx').data-unrotated_strain_map.get_slice('e_yy').data) + (cost2-sint2)*unrotated_strain_map.get_slice('e_xy').data
+    rotated_strain_map.data[:,:,2] = sint2*unrotated_strain_map.get_slice('e_xx').data + 2*cost*sint*unrotated_strain_map.get_slice('e_xy').data + cost2*unrotated_strain_map.get_slice('e_yy').data
+    rotated_strain_map.data[:,:,3] = unrotated_strain_map.get_slice('theta').data
 
-    rotated_strain_map.data[:,:,4] = unrotated_strain_map.slices['mask']
+    rotated_strain_map.data[:,:,4] = unrotated_strain_map.get_slice('mask').data
     return rotated_strain_map
 
 
